##############################################################################
# scan.drifter reads the simulated drifter files.  The output is a list of
# drifters.  Each drifter is arranged into a data frame with two fields,
# latitude and longitude.  This function handles both the regular output
# file and the file with insertion from the simulation program.
##############################################################################

scan.drifter <- function(filename) 
{
	num.per.line <- count.fields(filename)

	if (all(num.per.line == num.per.line[1]))  #The file is rectangular
	{
		num.drifters <- num.per.line[1]/2
		a <- matrix(scan(filename), nrow=2*num.drifters)
		b <- vector("list", num.drifters)
		for (i in 1:num.drifters)
		  b[[i]] <- data.frame(latitude=a[2*i-1,], longitude=a[2*i,])
	}
	else	# One drifter per line with variable length
	{
		data <- scan(filename)
		a <- split(data, rep(1:length(num.per.line), num.per.line))

		b <- vector("list", length(num.per.line))
		for (i in 1:length(num.per.line))
		{
	  	  temp <- split(a[[i]], rep(1:2, num.per.line[i]/2))
		  b[[i]] <- data.frame(latitude=temp[[1]], longitude=temp[[2]])
		}
	}
	b
}

